import React, { useEffect, useState } from 'react'
import { publicFetch } from '../../util/fetcher'
import AutomatedAnswer from '../automated-answer'
import NoAutomatedAnswer from '../automated-answer/no-automated-answer'
import { Spinner } from '../icons'

import styles from './automated-answer-container.module.css'

const AutomatedAnswerContainer = ({ question_id }) => {
  const [loading, setLoading] = useState(true)
  const [answer, setAnswer] = useState()
  const [error, setError] = useState({
    status: '',
    action: '',
    button: '',
    message: ''
  })

  useEffect(() => {
    const fetchAutomatedAnswer = async () => {
      try {
        const response = await publicFetch.get(`automatedanswer/${question_id}`)
        if (response.status == 200) setAnswer(response.data)
        else setServerError({ response })
      } catch (error) {
        setServerError(error)
      }
      setLoading(false)
    }
    fetchAutomatedAnswer()
  }, [question_id])

  const setServerError = (error) => {
    if (error.response.status == 404) {
      setError({
        status: '404',
        action: 'create',
        button: 'Generate One',
        message: 'No automated answer found for this question'
      })
    } else {
      setError({
        status: '500',
        action: 'tryagain',
        button: 'Try again',
        message: 'Server error, Please try again'
      })
    }
  }

  return (
    <div className={styles.container}>
      <div className={styles.header}>
        <div className={styles.fill}>
          <h2>Automated Answer</h2>
        </div>
      </div>
      <div className={styles.wrapper}>
        {loading ? (
          <Spinner className={styles.spinner} />
        ) : answer != null ? (
          <AutomatedAnswer automatedAnswer={answer.automatedanswer} />
        ) : (
          <NoAutomatedAnswer question_id={question_id} error={error} />
        )}
      </div>
    </div>
  )
}

export default AutomatedAnswerContainer
